@@ -12,6 +12,9 @@ class RainbowWithModel(Rainbow):
     # which fluxlike keys will respond to math between objects
     _keys_that_respond_to_math = ["flux", "model"]
 
+    # which keys get uncertainty weighting during binning
+    _keys_that_get_uncertainty_weighting = ["flux", "model", "uncertainty"]
+
     @property
     def residuals(self):
         """
